@@ -1,6 +1,10 @@
-from typing import Any, Dict, List
+from typing import Any
+from typing import Dict
+from typing import List
 
-from pytezos.michelson.forge import forge_array, forge_base58, optimize_timestamp
+from pytezos.michelson.forge import forge_array
+from pytezos.michelson.forge import forge_base58
+from pytezos.michelson.forge import optimize_timestamp
 
 
 def bump_fitness(fitness: List[str]) -> List[str]:
