@@ -1,15 +1,21 @@
 from typing import List
+from typing import Tuple
+from typing import Type
+from typing import cast
 
 from pytezos.context.abstract import AbstractContext
-from pytezos.michelson.instructions.base import MichelsonInstruction, Wildcard, format_stdout
+from pytezos.michelson.instructions.base import MichelsonInstruction
+from pytezos.michelson.instructions.base import Wildcard
+from pytezos.michelson.instructions.base import format_stdout
+from pytezos.michelson.micheline import Micheline
 from pytezos.michelson.stack import MichelsonStack
+from pytezos.michelson.types.base import MichelsonType
 
 
 class PushInstruction(MichelsonInstruction, prim='PUSH', args_len=2):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
-        res_type, literal = cls.args  # type: Type[MichelsonType], Type[Micheline]  # type: ignore
+        res_type, literal = cast(Tuple[Type[MichelsonType], Type[Micheline]], cls.args)
         assert res_type.is_pushable(), f'{res_type.prim} contains non-pushable arguments'
         res = res_type.from_literal(literal)
         stack.push(res)
@@ -18,7 +24,6 @@ class PushInstruction(MichelsonInstruction, prim='PUSH', args_len=2):
 
 
 class DropnInstruction(MichelsonInstruction, prim='DROP', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         count = cls.args[0].get_int()  # type: ignore
@@ -28,7 +33,6 @@ class DropnInstruction(MichelsonInstruction, prim='DROP', args_len=1):
 
 
 class DropInstruction(MichelsonInstruction, prim='DROP'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         dropped = stack.pop1()
@@ -37,7 +41,6 @@ class DropInstruction(MichelsonInstruction, prim='DROP'):
 
 
 class DupnInstruction(MichelsonInstruction, prim='DUP', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         depth = cls.args[0].get_int() - 1  # type: ignore
@@ -50,7 +53,6 @@ class DupnInstruction(MichelsonInstruction, prim='DUP', args_len=1):
 
 
 class DupInstruction(MichelsonInstruction, prim='DUP'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         res = stack.peek().duplicate()
@@ -60,7 +62,6 @@ class DupInstruction(MichelsonInstruction, prim='DUP'):
 
 
 class SwapInstruction(MichelsonInstruction, prim='SWAP'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         a, b = stack.pop2()
@@ -71,7 +72,6 @@ class SwapInstruction(MichelsonInstruction, prim='SWAP'):
 
 
 class DigInstruction(MichelsonInstruction, prim='DIG', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         depth = cls.args[0].get_int()  # type: ignore
@@ -84,7 +84,6 @@ class DigInstruction(MichelsonInstruction, prim='DIG', args_len=1):
 
 
 class DugInstruction(MichelsonInstruction, prim='DUG', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         depth = cls.args[0].get_int()  # type: ignore
@@ -97,7 +96,6 @@ class DugInstruction(MichelsonInstruction, prim='DUG', args_len=1):
 
 
 class CastIntruction(MichelsonInstruction, prim='CAST', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         res = stack.pop1()
@@ -110,7 +108,6 @@ class CastIntruction(MichelsonInstruction, prim='CAST', args_len=1):
 
 
 class RenameInstruction(MichelsonInstruction, prim='RENAME'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         return cls()
