@@ -1,11 +1,13 @@
-from typing import Any, Dict, Optional
+from typing import Any
+from typing import Dict
+from typing import Optional
 
 from pytezos.operation.forge import forge_operation
 
-DEFAULT_CONSTANTS = dict(
-    hard_gas_limit_per_operation=1040000,
-    hard_storage_limit_per_operation=60000,
-)
+DEFAULT_CONSTANTS = {
+    'hard_gas_limit_per_operation': 1040000,
+    'hard_storage_limit_per_operation': 60000,
+}
 # FIXME: Guessed for sandbox tests to pass
 DEFAULT_TRANSACTION_GAS_LIMIT = 1451
 DEFAULT_TRANSACTION_STORAGE_LIMIT = 257
@@ -15,7 +17,11 @@ MINIMAL_MUTEZ_PER_GAS_UNIT = 0.1
 
 
 def calculate_fee(
-    content: Dict[str, Any], consumed_gas: int, extra_size: int, reserve=10, minimal_nanotez_per_gas_unit: Optional[int] = None
+    content: Dict[str, Any],
+    consumed_gas: int,
+    extra_size: int,
+    reserve=10,
+    minimal_nanotez_per_gas_unit: Optional[int] = None,
 ) -> int:
     """Calculate minimal required operation fee.
 
@@ -31,7 +37,11 @@ def calculate_fee(
     return fee + reserve
 
 
-def default_fee(content: Dict[str, Any], gas_limit: Optional[int] = None, minimal_nanotez_per_gas_unit: Optional[int] = None) -> int:
+def default_fee(
+    content: Dict[str, Any],
+    gas_limit: Optional[int] = None,
+    minimal_nanotez_per_gas_unit: Optional[int] = None,
+) -> int:
     """Take hard gas limit instead of precise amount (no simulation) and calculate fee.
 
     :param content: operation content {..., "kind": "transaction", ... }
@@ -58,11 +68,13 @@ def default_gas_limit(
     values: Dict[str, int] = {
         'reveal': 1000,
         'delegation': 1000,
-        'origination': constants['hard_gas_limit_per_operation'],
+        'origination': int(constants['hard_gas_limit_per_operation']),
         'transaction': (
-            constants['hard_gas_limit_per_operation'] if content.get('destination', '').startswith('KT') else DEFAULT_TRANSACTION_GAS_LIMIT
+            int(constants['hard_gas_limit_per_operation'])
+            if content.get('destination', '').startswith('KT')
+            else DEFAULT_TRANSACTION_GAS_LIMIT
         ),
-        'register_global_constant': constants['hard_gas_limit_per_operation'],
+        'register_global_constant': int(constants['hard_gas_limit_per_operation']),
     }
     return values[content['kind']]
 
@@ -81,12 +93,12 @@ def default_storage_limit(
     values: Dict[str, int] = {
         'reveal': 0,
         'delegation': 0,
-        'origination': constants['hard_storage_limit_per_operation'],
+        'origination': int(constants['hard_storage_limit_per_operation']),
         'transaction': (
-            constants['hard_storage_limit_per_operation']
+            int(constants['hard_storage_limit_per_operation'])
             if content.get('destination', '').startswith('KT')
             else DEFAULT_TRANSACTION_STORAGE_LIMIT
         ),
-        'register_global_constant': constants['hard_storage_limit_per_operation'],
+        'register_global_constant': int(constants['hard_storage_limit_per_operation']),
     }
     return values[content['kind']]
