@@ -272,6 +272,34 @@ class ScriptsRunCodeQuery(RpcQuery, path='/chains/{}/blocks/{}/helpers/scripts/r
         return self._post(json=invocation)
 
 
+class ScriptsRunScriptViewQuery(RpcQuery, path='/chains/{}/blocks/{}/helpers/scripts/run_script_view'):
+    def post(self, invocation):
+        """Simulate a call to a michelson view
+
+        invocation format:
+
+        .. code-block:: python
+
+            {
+                "contract": <address>,
+                "view": <string>,
+                "input": <michelson expression>,
+                "unlimited_gas": <boolean>,
+                "chain_id": <base58 encoded>,
+                "source": <account address>,  // optional
+                "payer": <account address>,  // optional
+                "gas": <bignum>,  // optional
+                "unparsing_mode": <Readable | Optimized | Optimized_legacy>,
+                "now": <integer>,  // optional
+                "level": <integer>,  // optional
+            }
+
+        :param invocation: JSON input
+        :returns: Resulting storage, spawned operations, and bigmap diff
+        """
+        return self._post(json=invocation)
+
+
 class ScriptsRunOperationQuery(RpcQuery, path='/chains/{}/blocks/{}/helpers/scripts/run_operation'):
     def post(self, operation):
         """Run an operation without signature checks.
